
#pragma once

#ifndef  _DX_DLLDEFINE_H_
#define _DX_DLLDEFINE_H_


// ******************************************************************* //
// Define
// ******************************************************************* //
#define MAX_DEVICE_NUM			10

#define COMI_DX101	0xF101
#define COMI_DX201	0xF201
#define COMI_DX301	0xF301
#define COMI_DX501	0xF501

#define MAX_INTERRUPT_COUNT	 10

typedef char			t_char;
typedef unsigned char	t_byte;
typedef bool			t_bool;
typedef short			t_i16;
typedef unsigned short  t_ui16;
typedef int				t_i32;
typedef unsigned int	t_ui32;
typedef t_ui16			t_word;
typedef t_ui32			t_dword;
typedef float			t_f32;
typedef double			t_f64;

// ******************************************************************* //
// FUNCTION prototype
// ******************************************************************* //
// Interrupt Handler Callback Function Prototype //
typedef void (WINAPI *TIntHandler) (LPVOID lParam); 

// ******************************************************************* //
// Structures
// ******************************************************************* //
typedef struct 
{
	USHORT	wSubSysID;
	ULONG	nInstance;
	char	szDevName[20];
	UCHAR	bDevCaps; // 0bit-A/D, 1bit-D/A, 2bit-DIO, 3bit-Counter,
	UCHAR	nNumAdChan, nNumDaChan, nNumDiChan, nNumDoChan, nNumCntrChan, nNumPlsgenChan;
}TDXComiDevInfo;

typedef struct  
{
	ULONG nNumCount;
	USHORT nIntrType[MAX_INTERRUPT_COUNT];
	ULONG  EventID[MAX_INTERRUPT_COUNT];
}TDxInterruptState;

// ******************************************************************* //
// Enum Define
// ******************************************************************* //
typedef enum {
	dxDLOG_TRACE=0, /* Log Mode Trace */
	dxDLOG_FILE=1   /* Log Mode File */
}TDxLogType;

typedef enum {
	dxDLOG_DISABLE=0,/* Log Mode Off */
	dxDLOG_SET=1,     /* Set functions */
	dxDLOG_GET=2,		/* Set functions + get functions */
	dxDLOG_OUT=3,	/* Output Functions */
	dxDLOG_ALL=4,    /* All Output + Input Functions */
}TDxLogLevel;

typedef enum {
	dxTE_POSITIVE=0,/* Positive edge */
	dxTE_NEGATIVE=1, /* Negative edge */
	dxTE_ALL
}TDxEdgeType; /* A/I Scan Trigger Event Signal Edge Type */

typedef enum {
	dxFALSE=0,
	dxTRUE=1
}TDxBool; 

typedef enum {
	dxDIR_P=0,/* (+) Direction */
	dxDIR_N=1/* (-) Direction */
}TDxDir;

typedef enum {
	dxINV_FALLING=0, /* Inverse Falling */
	dxINV_RISING=1	 /* Inverse Rising */
}TDxInverse;

typedef enum {
	dxDI_ONLY=0,/* All channels are digital input                                                */
	dxDI_DO=1,  /* The first half channels are input and the latter half channels are for output */
	dxDO_DI=2,  /* The first half channels are output and the latter half channels are for input */
	dxDO_ONLY=3 /* All channels are digital output                                               */
}TDxDioUsage; /* DIO Usage */

typedef enum {
	dxAI_SINGLE=0,/* AI Single mode*/
	dxAI_DIFF=1,	  /* AI differential mode */
	dxAI_REF=2,
	dxAI_DA=3
}TDxAiInputMode;

typedef enum {
	dxTRS_SINGLE=0, /* Single data transfer (low performance) */
	dxTRS_BLOCK=1,  /* Block data transfer (high performance) */
}TDxAiScanTrs; /* A/I Scan Data Transfer Method */

typedef enum {
	dxTRG_S=0,     /* Trigger Source clock */
	dxTRG_E=1,	   /* Trigger External clock */
	dxTRG_E_SCAN=2 /* Trigger External scan */
}TDxAiScanTriggerMode;

typedef enum {
	dxAIF_NONE=0,
	dxAIF_AVG=1,/* M3 Moving Average */
	dxAIF_LPF=2,/* M3 LowPass Filter */
	dxAIF_TUSTIN_LPF=3,/* M3 TUSTIN LowPass Filter */
	dxAIF_BUTTERWORTH=4,/* M3 BUTTERWORTH LowPass Filter */
	dxAIF_HPF=5,/* M3 HighPass Filter */
	dxAIF_BPF=6 /* M3 BandPass Filter */
}TDxAiFilter;

typedef enum{
	dxCMODE_DISABLE=0,/* Counter Mode Disable */
	dxCMODE_SRC_SOFT0=1,/* Counter Mode Soft set Default Value */
	dxCMODE_SRC_EXT0=2,/* Counter Mode External Trigger Signal set Default Value */
	dxCMODE_SRC_SOFT1=3,/* Counter Mode Soft set Value 0 */
	dxCMODE_SRC_EXT1=4/* Counter Mode External Trigger Signal set Value 0 */
}TDxCntSourceMode;

typedef enum {
	dxCHOLD_LOW=0,/* Counter Hold Value 0 */
	dxCHOLD_HIGH=1/* Counter Hold Value 1 */
}TDxCntHold;

typedef enum {
	dxCFILTER_FREQ_NONE=0, // Frequency Disable
	dxCFILTER_FREQ0=1, //  2.5 MHz
	dxCFILTER_FREQ1=2, // 1.25 MHz
	dxCFILTER_FREQ2=3, //  625 Khz
	dxCFILTER_FREQ3=4 // 312.5 Khz
}TDxCntFilterClock;

typedef enum {
	dxCNT_FALLING=0,
	dxCNT_RISING=1
}TDxCntEdge;

typedef enum {
	dxCNT_UP=0,
	dxCNT_DOWN=1
}TDxCntUpDown;

typedef enum {
	dxCNT_POARTA=0,
	dxCNT_20MHZ=1
}TDxCntSource;

typedef enum {
	dxCSET_PARAM0=0,
	dxCSET_PARAM1=1
}TDxCntSelectParameter;

typedef enum {		// AD			// DA
	dxRANGE_V0=0, // 0~1v		// 0~5v
	dxRANGE_V1=1, // 0~2v		// 0~10v
	dxRANGE_V2=2, // 0~5v		// 0~10.8v
	dxRANGE_V3=3, // 0~10v		// -5~5v
	dxRANGE_V4=4, // -1~1v		// -10~10v
	dxRANGE_V5=5,  // -2~2v		// -10.8v~10.8v
	dxRANGE_V6=6, // -5~5v		//	none
	dxRANGE_V7=7 // -10~10v	// none
}TDxVoltRange;

typedef enum _TDxEcInMode{
	dxEC_x4AB=0,
	dxEC_x2AB=1,
	dxEC_x1AB=2,
	dxEC_PLSDIR=3,
	dxEC_CWCCW=4
}TDxEcInMode;

typedef enum _TDxEcInverse{
	dxEC_INV_NONE=0, dxEC_INV_A=1, dxEC_INV_B=2, dxEC_INV_AB=3, dxEC_INV_Z=4, 
	dxEC_INV_AZ=5, dxEC_INV_BZ=6, dxEC_INV_ABZ=7
}TDxEcInverse;

typedef enum _TDxEcClock{
	dxEC_10M=0, /* 10M*3 Filter */
	dxEC_5M=1   /* 5M*3 Filter */
}TDxEcClock;

typedef enum _TDxLTCmode{
	dxLTC_NONE=0,
	dxLTC_R_EDGE=1, /* Rising Edge */
	dxLTC_F_EDGE=2, /* Falling Edge */
	dxLTC_BI_EDGE=3 /* both Risng & Falling Edge */
}TDxLTCmode;

typedef enum _TDxCmpMode{
	dxCMP_REGULAR=0,
	dxCMP_RANDOM=1
}TDxCmpMode;


// Interrupt Handler Type //
typedef enum _TDxIntHandlerType{
	dxIHT_MESSAGE=0, dxIHT_EVENT, dxIHT_CALLBACK
}TDxIntHandlerType;

typedef enum {
	dxINT_DI_SINGLE=0,
	dxINT_DI_MULTI=1,
	dxINT_DI_MULTI_ONE=2
}TDxIntDiMode;

typedef enum {
	dxINT_UP=0,
	dxINT_ON=0,
	dxINT_DOWN=1,
	dxINT_OFF=1,
	dxINT_BI=2
}TDxIntUpDown;

// ******************************************************************* //
// Error Code
// ******************************************************************* //
#define dxERR_NONE							0
#define dxERR_DEV_NOT_EXIST				-1000
#define dxERR_UNSUPORTED_FUNC			-1001

#define dxERR_INVALID_DEVICE_HANDLE	-1010
#define dxERR_INVALID_PARAMETER		-1011
#define dxERR_INVALID_CHANNEL			-1012
#define dxERR_INVALID_RANGE				-1013
#define dxERR_INVALID_SETTING			-1014
#define dxERR_PARAMETER_NONE			-1015

#define dxERR_DEVICE_LOAD_FAIL			-1200
#define dxERR_FILE_OPEN_FAIL				-1201

#define dxERR_MEM_ALLOC_FAIL			-2000

#define dxERR_CNT_MODE_DISABLE		-3000
#define dxERR_CNT_MODE_EXTERNAL		-3001

#define dxERR_DSP_DOES_NOT_REPLY		-4000

#define dxERR_AD_SCAN_RUNNING		-5000
#define dxERR_AD_SCAN_NEED_CH_SET	-5001
#define dxERR_AD_SCAN_ONLY_FILTER		-5002

#define dxERR_INT_NEED_HANDLER		-6000
#define dxERR_INT_DUPLICATED_ID			-6001

#endif